from ..app.base_context import UserInfo as UserInfo, get_current_user_info as get_current_user_info, set_current_user_info as set_current_user_info
from ..exception.service_exception import raise_permission_exception as raise_permission_exception, raise_request_validation_error as raise_request_validation_error

class TenantManager:
    @classmethod
    def disable(cls) -> None: ...
    @classmethod
    def set(cls, *, user_name, tenant_id) -> None: ...
    @classmethod
    def apply_tenant_condition(cls, *, db_model, conditions): ...
    @classmethod
    def get_tenant_condition(cls, *, db_model): ...
    @classmethod
    def set_field_with_user_and_tenant(cls, db_model) -> None: ...
    @classmethod
    def check_permission(cls, db_model) -> None: ...



from ..exception.service_exception import raise_request_validation_error as raise_request_validation_error
from ..schemas.query_request import Condition as Condition, QueryLogicOperation as QueryLogicOperation, QueryRequest as QueryRequest, QuerySimpleCondition as QuerySimpleCondition
from ..type.var import SQLModelDB as SQLModelDB, SQLModelResponse as SQLModelResponse
from .query_field import convert_datetime_iso_to_standard as convert_datetime_iso_to_standard, get_class_fields_with_sa_type as get_class_fields_with_sa_type
from .tenant_checker import TenantManager as TenantManager
from sqlmodel import SQLModel as SQLModel
from typing import Any

class QueryBuilder:
    @classmethod
    def build_list(cls, query_fields, items, model_class: type[SQLModelDB], response_class: type[SQLModelResponse] = None): ...
    @staticmethod
    def get_order_by(query: QueryRequest, model_class: type[SQLModel]) -> Any: ...
    @classmethod
    def get_fields(cls, query: QueryRequest, model_class: type[SQLModel]) -> Any: ...
    @classmethod
    def get_where(cls, condition: Condition, model_class: type[SQLModel]) -> Any: ...
    @staticmethod
    def get_condition_python_value(field, field_type, field_value): ...
    @classmethod
    def method_name(cls, fields, item, tag) -> None: ...
    @classmethod
    def build_tree(cls, items, *, query: QueryRequest, model_class): ...
    @classmethod
    def check_query_request(cls, query) -> None: ...



from ..utils.core_utils import CoreUtil as CoreUtil
from .model import LicenseModel as LicenseModel
from _typeshed import Incomplete

class LicenseBuilder:
    license: Incomplete
    def __init__(self) -> None: ...
    def generate(self, *, customer_id=None, machine_id=None, features=None, valid_days=None, license_type=None, product_name=None): ...



from ..enum.label_enum import LabelEnum as LabelEnum
from ..enum.resolve_enum import resolve_enum_field as resolve_enum_field

class EnumService:
    @classmethod
    def resolve_field(cls, data: dict, field_name: str, enum_cls: type[LabelEnum]) -> None: ...



#!/usr/bin/env python3
# -*- coding:utf-8 -*-
# @License  ：(C)Copyright 2025, 数道智融科技
# @Author   ：李锋
# @Software ：PyCharm
# @Date     ：2025/6/29 下午10:17
# @Desc     ：

from typing import Literal

from pydantic import BaseModel, Field


class ContextConfigSetting(BaseModel):
    name: str = Field(..., description="应用唯一标识")
    enabled: bool = Field(True, description="是否启用")
    storage: Literal["disabled", "redis", "disk"] = Field(description="持久化方式")
    desc: str = Field("", description="描述")
    redis: str = Field("Default", description="Redis配置的id值")
    disk: str = Field("Default", description="文件存储配置的id值")
    database: str = Field("Default", description="数据库配置的id值")



from ..generate.config import GeneratorConfig as GeneratorConfig
from ..generate.template_builder import TemplateBuilder as TemplateBuilder
from ..logger.logging_ import logging as logging
from _typeshed import Incomplete

class GeneratorService:
    config: Incomplete
    builder: Incomplete
    def __init__(self, config: GeneratorConfig) -> None: ...
    def generator_all(self) -> None: ...
    def generator_schema(self, schema_name) -> None: ...
    def generator_table(self, table_name, schema_name) -> None: ...
    def generator_view(self, view_name, schema_name) -> None: ...



#!/usr/bin/env python3
# -*- coding:utf-8 -*-
# @License  ：(C)Copyright 2025, 数道智融科技
# @Author   ：李锋
# @Software ：PyCharm
# @Date     ：2025/8/29 下午5:15
# @Desc     ：


from typing import List, Union, Literal, Optional

from pydantic import BaseModel, field_validator, Field

# 定义前向引用类型
Condition = Union['QueryLogicOperation', 'QuerySimpleCondition']


class QuerySimpleCondition(BaseModel):
    """ 查询条件 """
    field: str = Field(..., description="要查询的字段名")
    op: str = Field(..., description="逻辑运算符")
    val: Union[str, int, float, bool, List, None] = Field(..., description="要查询的值")

    class Config:
        extra = "forbid"


class QueryLogicOperation(BaseModel):
    """ 逻辑操作（AND 或 OR）"""
    type: str = Field(..., description="逻辑操作符，'AND' 或 'OR'")
    conditions: List[Condition] = Field(None, description="子条件列表")

    @classmethod
    @field_validator("type")
    def validate_type(cls, v: str) -> str:
        if v.upper() not in ("AND", "OR"):
            raise ValueError("QueryRequest的type必须是'AND'或'OR'")
        return v

    class Config:
        extra = "forbid"


# 解决前向引用
QueryLogicOperation.model_rebuild()
QuerySimpleCondition.model_rebuild()


# 排序条件模型
class QuerySortCondition(BaseModel):
    """ 排序条件 """
    field: str = Field(..., description="排序字段")
    order: Literal["asc", "desc"] = Field("asc", description="排序方向")


class TreeConfig(BaseModel):
    field_id: Optional[str] = Field(None, description="当前节点的ID，用于PID型树")
    field_pid: Optional[str] = Field(None, description="当前节点的PID，用于PID型树")
    field_tag: Optional[str] = Field(None, description="当前的标签")

    # 子节点，外键约束
    field_children: Optional[str] = Field(None, description="用于 外键约束 的Tree")

    children_fields: Optional[List[str]] = Field(None, description="子节点字段")
    children_orderby: Optional[str] = Field(None, description="子节点排序")
    # 子节点 PID 处理
    children_tag: Optional[str] = Field(None, description="子节点标签")
    children_id: Optional[str] = Field(None, description="子节点的ID，用于PID型树")
    children_pid: Optional[str] = Field(None, description="子节点的PID，用于PID型树")


class QueryRequest(QueryLogicOperation):
    """ 顶层查询模型 """
    fields: Optional[List[str]] = Field(None, description="指定要返回的字段")
    type: Optional[str] = Field("AND", description="逻辑操作类型，'AND' 或 'OR'")
    conditions: List[Condition] = Field(None, description="子条件列表")
    orderby: List[QuerySortCondition] = Field(None, description="排序条件列表")
    page: Optional[int] = Field(None, ge=1, description="第几页")
    size: Optional[int] = Field(None, ge=1, le=1000, description="每页多少个")
    # paging: Optional[bool] = Field(True, description="返回分页")
    format: Optional[Literal["list", "page", "tree"]] = Field(None, description="返回格式")
    tree: Optional[TreeConfig] = Field(None, description="树型格式的配置项")



from _typeshed import Incomplete
from fastapi.exceptions import RequestValidationError as RequestValidationError
from pydantic import ValidationError as ValidationError
from typing import Any

ERROR_MESSAGES: Incomplete

def format_request_validation_error(exc: RequestValidationError) -> list[dict[str, Any]]: ...
def format_pydantic_validation_error(exc: ValidationError) -> list[dict[str, Any]]: ...



from ..config.app_config import AppConfig as AppConfig
from ..logger.logging_ import logging as logging
from sqlalchemy.engine import Engine as Engine
from sqlalchemy.ext.asyncio import AsyncEngine as AsyncEngine

class DatabaseEngine:
    def __new__(cls, name: str = None, async_engine: bool = True): ...
    def get_async_engine(self, name) -> AsyncEngine: ...
    def support_schema(self, name: str) -> bool: ...
    def get_engine(self, name) -> Engine: ...
    def close(self) -> None: ...
    async def async_close(self) -> None: ...
    def __del__(self) -> None: ...



from ..config.app_config import AppConfig as AppConfig
from ..logger.logging_ import logging as logging

class RedisEngine:
    def __new__(cls): ...
    def get_connection(self, pool_name): ...
    def close(self) -> None: ...
    def __del__(self) -> None: ...



#!/usr/bin/env python3
# -*- coding:utf-8 -*-
# @License  ：(C)Copyright 2025, 数道智融科技
# @Author   ：李锋
# @Software ：PyCharm
# @Date     ：2025/9/26 上午11:57
# @Desc     ：

from ..enum.label_enum import LabelEnum


class UserStatus(LabelEnum):
    """用户状态枚举"""
    ACTIVE = (1, "活跃", "账号正常")
    INACTIVE = (2, "停用", "账号已禁用")
    PENDING = (3, "待激活", "注册后未激活")


class Gender(LabelEnum):
    """性别枚举"""
    UNKNOWN = (0, "未知", "未设置性别")
    MALE = (1, "男", "男性用户")
    FEMALE = (2, "女", "女性用户")


class AccountType(LabelEnum):
    """账户类型枚举"""
    PERSONAL = (1, "个人", "个人用户账户")
    ENTERPRISE = (2, "企业", "企业用户账户")
    ADMIN = (99, "管理员", "系统管理员账户")



from ..exception.service_exception import ServiceErrorException as ServiceErrorException
from ..portal_auth.entity_table.auth_user import AuthUserResponse as AuthUserResponse
from ..services.auth_service import AuthService as AuthService
from ..services.db_engine_service import DBEngineService as DBEngineService
from .auth_data_rule import AuthDataRule as AuthDataRule
from _typeshed import Incomplete
from fastapi import APIRouter, Request as Request
from sqlmodel.ext.asyncio.session import AsyncSession

class AuthRouter(APIRouter):
    permission_rules: Incomplete
    default_role: Incomplete
    auth_role: Incomplete
    auth_obj: Incomplete
    auth_act: Incomplete
    db_config: Incomplete
    data_rules: list[AuthDataRule]
    def __init__(self, default_role: str | None = None, auth_role: str | None = None, auth_obj: str | None = None, auth_act: str | None = None, db_config_name: str | None = None, *args, **kwargs) -> None: ...
    async def get_async_session(self) -> AsyncSession: ...
    def api_route(self, path: str, *, auth: bool = True, auth_role: str | None = None, auth_obj: str | None = None, auth_act: str | None = None, **kwargs): ...
    def add_auth_data_rule(self, path: str, **kwargs): ...
    def get(self, path: str, *, auth: bool = True, auth_role: str | None = None, auth_obj: str | None = None, auth_act: str | None = None, **kwargs): ...
    def post(self, path: str, *, auth: bool = True, auth_role: str | None = None, auth_obj: str | None = None, auth_act: str | None = None, **kwargs): ...
    def put(self, path: str, *, auth: bool = True, auth_role: str | None = None, auth_obj: str | None = None, auth_act: str | None = None, **kwargs): ...
    def patch(self, path: str, *, auth: bool = True, auth_role: str | None = None, auth_obj: str | None = None, auth_act: str | None = None, **kwargs): ...
    def delete(self, path: str, *, auth: bool = True, auth_role: str | None = None, auth_obj: str | None = None, auth_act: str | None = None, **kwargs): ...

def get_data_rule_from_request(*, request: Request, data_rules: list[AuthDataRule]) -> AuthDataRule | None: ...



from ..config.app_config import AppConfig as AppConfig
from ..engine.casbin_engine import PermissionEngine as PermissionEngine
from ..exception.service_exception import PermissionException as PermissionException
from ..logger.logging_ import logging as logging
from _typeshed import Incomplete

class PermissionService:
    engine: Incomplete
    def __init__(self) -> None: ...
    async def initialize(self, permission_rules) -> None: ...
    async def has_role(self, user, role): ...
    def has_permission(self, user, obj, act): ...
    async def add_permission(self, *, role, obj, act) -> None: ...
    async def add_role_for_user(self, *, user, role) -> None: ...
    async def add_role_for_role(self, *, parent_role, child_role) -> None: ...
    async def save_policy(self) -> None: ...



#!/usr/bin/env python3
# -*- coding:utf-8 -*-
# @License  ：(C)Copyright 2025, 数道智融科技
# @Author   ：李锋
# @Software ：PyCharm
# @Date     ：2025/9/17 上午11:06
# @Desc     ：

from sqlalchemy import Column, Integer, String

from .. import get_schema_name, auth_registry

Base = auth_registry.generate_base()


class AuthRule(Base):
    __tablename__ = "t_auth_rule"
    __table_args__ = {"schema": f"{get_schema_name()}", "comment": "访问控制规则表"}

    id = Column(Integer, primary_key=True, comment="内码")
    ptype = Column(String(255), comment="类型")
    v0 = Column(String(255), comment="角色/用户")
    v1 = Column(String(255), comment="资源/角色")
    v2 = Column(String(255), comment="动作")
    v3 = Column(String(255), comment="租户")
    v4 = Column(String(255))
    v5 = Column(String(255))

    def __str__(self):
        arr = [self.ptype]
        for v in (self.v0, self.v1, self.v2, self.v3, self.v4, self.v5):
            if v is None:
                break
            arr.append(v)
        return ", ".join(arr)

    def __repr__(self):
        return '<CasbinRule {}: "{}">'.format(self.id, str(self))



from ..config.app_config import AppConfig as AppConfig
from ..exception.service_exception import AuthException as AuthException, LoginException as LoginException
from ..logger.logging_ import logging as logging
from ..portal_auth.entity_table.auth_user import AuthLogin as AuthLogin, AuthPassword as AuthPassword, AuthUser as AuthUser, AuthUserResponse as AuthUserResponse
from ..services.data_service import DataService as DataService
from ..services.db_engine_service import DBEngineService as DBEngineService
from ..tools.tenant_checker import TenantManager as TenantManager
from .casbin_service import PermissionService as PermissionService
from _typeshed import Incomplete
from datetime import timedelta
from sqlmodel.ext.asyncio.session import AsyncSession as AsyncSession

class AuthService:
    TOKEN_SECRET_KEY: Incomplete
    TOKEN_ALGORITHM: str
    TOKEN_EXPIRE_MINUTES: Incomplete
    oauth2_scheme: Incomplete
    @classmethod
    def verify_password(cls, plain_password: str, hashed_password: str) -> bool: ...
    @classmethod
    def hash_password(cls, password: str) -> str: ...
    @classmethod
    def token_encode(cls, data: dict, expires_delta: timedelta | None = None) -> str: ...
    @classmethod
    def token_decode(cls, token) -> dict: ...
    @classmethod
    def get_permission(cls): ...
    @classmethod
    async def get_current_user(cls, token=..., db: AsyncSession = ...) -> AuthUserResponse: ...
    @classmethod
    async def logout(cls) -> None: ...
    @classmethod
    async def refresh(cls) -> None: ...
    @classmethod
    async def login(cls, *, db: AsyncSession, auth_login: AuthLogin): ...
    @classmethod
    async def modify_password(cls, db: AsyncSession, *, password_model: AuthPassword, current_user: AuthUserResponse): ...



from ..config.app_config import AppConfig as AppConfig
from ..logger.logging_ import logging as logging
from ..utils.core_utils import CoreUtil as CoreUtil
from pathlib import Path

class DiskEngine:
    def __new__(cls): ...
    def get_path(self, name: str, child_path: str = '') -> Path: ...
    def close(self) -> None: ...
    def __del__(self) -> None: ...



#!/usr/bin/env python3
# -*- coding:utf-8 -*-
# @License  ：(C)Copyright 2025, 数道智融科技
# @Author   ：李锋
# @Software ：PyCharm
# @Date     ：2025/6/22 下午6:32
# @Desc     ：

from typing import Literal, Optional, Dict, Any, List

from pydantic import BaseModel, Field

from .context import ContextConfigSetting


class LocalConfigSetting(BaseModel):
    engine: Literal["transformers", "vllm", "sentence_transformers"] = "transformers"
    engine_options: Dict[str, Any] = {}
    path: str = ""
    method_kwargs: Dict[str, Any] = {}


class RemoteConfigSetting(BaseModel):
    model: str = ""
    url: str = ""
    key: str = ""
    method_kwargs: Dict[str, Any] = {}


class ModelConfigSetting(BaseModel):
    name: str = Field(..., description="唯一标识")
    enabled: bool = Field(True, description="是否启用")
    proxy: Literal["local", "remote"] = "local"
    field_think: Optional[str] = Field("", description="思考模型的标签字段")
    local: LocalConfigSetting = LocalConfigSetting()
    remote: Optional[RemoteConfigSetting] = RemoteConfigSetting()


class ModelCollectionConfigSetting(BaseModel):
    context: Optional[List[ContextConfigSetting]] = Field(None, description="上下文配置")
    language_models: list[ModelConfigSetting] = Field(None, description="语言模型")
    embedding_models: list[ModelConfigSetting] = Field(None, description="嵌入模型")
    reranker_models: list[ModelConfigSetting] = Field(None, description="重排序模型")



from ..config.app_config import AppConfig as AppConfig
from ..logger.logging_ import logging as logging
from ..portal_auth.entity_table.auth_rule import AuthRule as AuthRule
from ..services.db_engine_service import DBEngineService as DBEngineService
from ..utils.core_utils import CoreUtil as CoreUtil

class PermissionEngine:
    def __new__(cls): ...
    def get_async_enforcer(self): ...
    async def check_table(self) -> None: ...



from ..exception.service_exception import DataNotFoundException as DataNotFoundException
from ..schemas.element import Paging as Paging
from ..schemas.query_request import QueryRequest as QueryRequest
from ..tools.query_builder import QueryBuilder as QueryBuilder
from ..tools.tenant_checker import TenantManager as TenantManager
from ..type.var import SQLModelCreate as SQLModelCreate, SQLModelDB as SQLModelDB, SQLModelResponse as SQLModelResponse, SQLModelUpdate as SQLModelUpdate
from sqlalchemy import ColumnElement
from sqlmodel.ext.asyncio.session import AsyncSession as AsyncSession
from typing import Any

class DataService:
    @classmethod
    def db_insert(cls, db: AsyncSession, *, db_model_class: type[SQLModelDB], create_model: SQLModelCreate | dict[str, Any]) -> SQLModelDB: ...
    @classmethod
    async def create(cls, db: AsyncSession, *, model_class: type[SQLModelDB], create_model: SQLModelCreate | dict[str, Any], response_class: type[SQLModelResponse] = None, auto_commit: bool = True) -> SQLModelDB | SQLModelResponse: ...
    @classmethod
    async def db_get(cls, db: AsyncSession, primary_id: int, *, db_model_class: type[SQLModelDB]) -> SQLModelDB | None: ...
    @classmethod
    async def read(cls, db: AsyncSession, primary_id: int, *, model_class: type[SQLModelDB], response_class: type[SQLModelResponse] = None) -> SQLModelDB | SQLModelResponse: ...
    @classmethod
    async def db_update(cls, db: AsyncSession, primary_id: int, *, model_class: type[SQLModelDB], update_model: SQLModelUpdate | dict[str, Any]) -> SQLModelDB | None: ...
    @classmethod
    async def update(cls, db: AsyncSession, primary_id: int, *, model_class: type[SQLModelDB], update_model: SQLModelUpdate | dict[str, Any], response_class: type[SQLModelResponse] = None, auto_commit: bool = True) -> SQLModelDB | SQLModelResponse: ...
    @classmethod
    async def db_delete(cls, db: AsyncSession, primary_id: int, *, db_model_class: type[SQLModelDB]) -> bool: ...
    @classmethod
    async def delete(cls, db: AsyncSession, primary_id: int, *, model_class: type[SQLModelDB], auto_commit: bool = True) -> bool: ...
    @classmethod
    async def query_columns(cls, db: AsyncSession, *, model_class: type[SQLModelDB], condition: list[ColumnElement] | ColumnElement | Any) -> SQLModelDB: ...
    @classmethod
    async def query(cls, db: AsyncSession, query: QueryRequest, *, model_class: type[SQLModelDB], response_class: type[SQLModelResponse]): ...
    @classmethod
    def get_primary_key_name(cls, model_class: type[SQLModelDB]) -> str | list[str] | None: ...



from .meta_foreign import MetaForeignColumn as MetaForeignColumn
from dataclasses import dataclass
from typing import Any

@dataclass
class MetaColumn:
    name: str
    type: Any
    sa_type: str | None
    nullable: bool
    default: str | None
    is_primary: bool
    comment: str = ...
    max_length: int | None = ...
    precision: int | None = ...
    scale: int | None = ...
    foreign_key: MetaForeignColumn | None = ...



from .meta_column import MetaColumn as MetaColumn
from .meta_foreign import MetaForeignColumn as MetaForeignColumn
from .meta_init_file import MetaInitFile as MetaInitFile
from dataclasses import dataclass
from sqlalchemy import inspect as inspect

@dataclass
class MetaTable:
    inspector = ...
    schema_name = ...
    support_schema = ...
    table_or_view_name = ...
    file_name = ...
    class_name = ...
    child_columns: list[MetaForeignColumn] = ...
    parent_columns: list[MetaForeignColumn] = ...
    base_columns: list[MetaColumn] = ...
    database_columns: list[MetaColumn] = ...
    response_columns: list[MetaColumn] = ...
    comment: str = ...
    generated_date: str = ...
    entity_imports: list[str] = ...
    init_file = ...
    table_args: str = ...
    def __init__(self, *, inspector: inspect, table_or_view_name, schema_name, support_schema, parent_foreign_keys) -> None: ...
    def get_database_columns(self) -> list[MetaColumn]: ...
    def get_base_columns(self) -> list[MetaColumn]: ...
    def get_response_columns(self) -> list[MetaColumn]: ...
    def get_columns(self) -> list[MetaColumn]: ...
    @staticmethod
    def get_sa_type(column_type, is_primary: bool) -> str: ...
    def get_comment(self): ...
    def get_import_shudaodao_core(self) -> str: ...
    def get_import_sqlmodel(self): ...



from dataclasses import dataclass

@dataclass
class MetaForeignColumn:
    schema_name: str
    alias_index: str
    constrained_table: str
    constrained_class: str
    constrained_column: str
    constrained_name: str
    referred_table: str
    referred_class: str
    referred_column: str
    referred_name: str
    def get_plural_name(self, source) -> str: ...
    @staticmethod
    def get_property_name(source: str) -> str: ...



from .. import get_engine_name as get_engine_name
from ...auth.auth_router import AuthRouter as AuthRouter
from ...config.app_config import AppConfig as AppConfig
from ...exception.service_exception import ServiceErrorException as ServiceErrorException
from ...services.auth_service import AuthService as AuthService
from ...services.data_service import DataService as DataService
from ...tools.tenant_checker import TenantManager as TenantManager
from ...utils.response_utils import ResponseUtil as ResponseUtil
from ..entity_table.auth_user import AuthLogin as AuthLogin, AuthPassword as AuthPassword, AuthRegister as AuthRegister, AuthUser as AuthUser, AuthUserResponse as AuthUserResponse
from _typeshed import Incomplete
from fastapi import Request as Request
from fastapi.security import OAuth2PasswordRequestForm as OAuth2PasswordRequestForm
from sqlalchemy import literal as literal
from sqlmodel.ext.asyncio.session import AsyncSession as AsyncSession

Auth_Controller: Incomplete

async def auth_register(register_model: AuthRegister, db: AsyncSession = ...): ...
async def auth_login(login_model: AuthLogin, db: AsyncSession = ...): ...
async def auth_token(request: Request, form_data: OAuth2PasswordRequestForm = ..., db: AsyncSession = ...): ...
async def auth_logout(): ...
async def auth_refresh(): ...
async def auth_me(current_user: AuthUserResponse = ...): ...
async def auth_me_password(password_model: AuthPassword, db: AsyncSession = ..., current_user: AuthUserResponse = ...): ...



from enum import IntEnum

class LabelEnum(IntEnum):
    def __new__(cls, value: int, label: str, description: str = ''): ...
    @classmethod
    def from_label(cls, label: str): ...
    @classmethod
    def labels(cls) -> list[str]: ...
    @property
    def label(self) -> str: ...
    @property
    def description(self) -> str: ...



#!/usr/bin/env python3
# -*- coding:utf-8 -*-
# @License  ：(C)Copyright 2025, 数道智融科技
# @Author   ：李锋
# @Software ：PyCharm
# @Date     ：2025/8/26 下午12:11
# @Desc     ：

# 其他类库的引用
from fastapi import Depends as _Depends
from sqlalchemy.ext.asyncio import create_async_engine as _create_async_engine
from sqlmodel import Relationship as _Relationship
from sqlmodel import SQLModel as _SQLModel
from sqlmodel import create_engine as _create_engine
from sqlmodel.ext.asyncio.session import AsyncSession as _AsyncSession

from .app.base_app import BaseApplication
from .auth.auth_router import AuthRouter
from .config.app_config import AppConfig
from .config.running_config import RunningConfig
from .engine.database_engine import DatabaseEngine
from .engine.disk_engine import DiskEngine
from .engine.redis_engine import RedisEngine
from .exception.register_handlers import register_exception_handlers
from .exception.service_exception import (
    AuthException,
    LoginException,
    PermissionException,
    ServiceErrorException,
    DataNotFoundException
)
from .generate.config import GeneratorConfig
from .logger.logging_ import logging
from .model.field import Field
from .schemas.query_request import QueryRequest
from .schemas.response import BaseResponse
from .services.auth_service import AuthService
from .services.data_service import DataService
from .services.db_engine_service import DBEngineService
from .services.enum_service import EnumService
from .services.generate_service import GeneratorService
from .utils.core_utils import CoreUtil
from .utils.generate_unique_id import get_primary_str, get_primary_id
from .utils.response_utils import ResponseUtil

# 其他类库的引用
AsyncSession = _AsyncSession
create_engine = _create_engine
create_async_engine = _create_async_engine
Depends = _Depends
SQLModel = _SQLModel
Relationship = _Relationship



from _typeshed import Incomplete
from typing import Any

def raise_request_validation_error(*, loc_type: str, msg: str): ...
def raise_permission_exception(*, message: str, errors: str = None): ...

class ShudaodaoException(Exception):
    code: Incomplete
    name: Incomplete
    errors: Incomplete
    message: Incomplete
    def __init__(self, code: int, name: str, message: str, errors: Any = None) -> None: ...

class LoginException(ShudaodaoException):
    def __init__(self, *, message: str, errors: str = None) -> None: ...

class AuthException(ShudaodaoException):
    def __init__(self, *, message: str, errors: str = None) -> None: ...

class PermissionException(ShudaodaoException):
    def __init__(self, *, message: str, errors: str = None) -> None: ...

class ServiceErrorException(ShudaodaoException):
    def __init__(self, *, message: str, errors: str = None) -> None: ...

class DataNotFoundException(ShudaodaoException):
    def __init__(self, *, message: str = '数据未找到', model_class: str | None = None, primary_id: int | None = None, primary_field: str | list[str] | None = None) -> None: ...



from ..config.app_config import AppConfig as AppConfig
from _typeshed import Incomplete

class UserInfo:
    user_name: Incomplete
    tenant_id: Incomplete
    tenant_enabled: Incomplete
    def __init__(self, user_name: str | None = None, tenant_id: int | None = None, tenant_enabled: bool | None = None) -> None: ...

def get_current_user_info() -> UserInfo: ...
def set_current_user_info(user_info: UserInfo): ...



#!/usr/bin/env python3
# -*- coding:utf-8 -*-
# @License  ：(C)Copyright 2025, 数道智融科技
# @Author   ：李锋
# @Software ：PyCharm
# @Date     ：2025/9/2 下午4:24
# @Desc     ：

from datetime import datetime
from typing import Optional, Any

from pydantic import EmailStr, model_validator, computed_field
from sqlalchemy import BigInteger, Integer
from sqlmodel import SQLModel

from .. import get_schema_name, RegistryModel
from ...model.field import Field
from ...schemas.core_enum import UserStatus
from ...schemas.response import BaseResponse
from ...services.enum_service import EnumService
from ...utils.generate_unique_id import get_primary_id


class AuthUser(RegistryModel, table=True):
    """ 数据模型 - 数据库表 T_Auth_User 结构模型 """
    __tablename__ = "t_auth_user"
    __table_args__ = {"schema": f"{get_schema_name()}", "comment": "鉴权用户表"}

    user_id: Optional[int] = Field(
        default_factory=get_primary_id, primary_key=True, sa_type=BigInteger,
        sa_column_kwargs={"comment": "内码"}, description="内码")
    user_name: str = Field(
        unique=True, index=True, max_length=50, sa_column_kwargs={"comment": "内码"}, description="用户名")
    pass_word: str = Field(sa_column_kwargs={"comment": "密码"}, description="密码")
    user_email: Optional[EmailStr] = Field(
        default=None, nullable=True, max_length=100, sa_column_kwargs={"comment": "邮件"}, description="邮件")
    is_active: bool = True
    user_status: Optional[UserStatus] = Field(default=None, nullable=True, sa_type=Integer)

    last_login: Optional[datetime] = Field(default_factory=lambda: datetime.now(), description="最后登录时间")

    create_by: Optional[str] = Field(default=None, max_length=50, nullable=True, description="创建人")
    create_at: Optional[datetime] = Field(default_factory=lambda: datetime.now(), nullable=True, description="创建日期")
    update_by: Optional[str] = Field(default=None, max_length=50, nullable=True, description="修改人")
    update_at: Optional[datetime] = Field(default_factory=lambda: datetime.now(), nullable=True, description="修改日期")
    tenant_id: Optional[int] = Field(default=None, nullable=True, sa_type=BigInteger, description="租户内码")


class AuthUserResponse(BaseResponse):
    # user_id: Optional[int] = Field(sa_type=BigInteger)
    user_name: str = Field(max_length=50)
    user_status: Optional[UserStatus]  # ← 枚举字段
    user_email: Optional[EmailStr] = Field(default=None, max_length=100)
    is_active: Optional[bool] = Field(default=None)

    create_by: Optional[str] = Field(default=None)
    create_at: Optional[datetime] = Field(default=None)
    update_by: Optional[str] = Field(default=None)
    update_at: Optional[datetime] = Field(default=None)

    @computed_field
    @property
    def user_status_label(self) -> str:
        return self.user_status.label if self.user_status else None


class AuthLogin(SQLModel):
    """ 登录模型 """
    user_name: str = Field(min_length=3, max_length=50)
    pass_word: str = Field(min_length=6)


class AuthRegister(SQLModel):
    user_name: str = Field(min_length=5, max_length=50)
    pass_word: str = Field(min_length=5)
    user_email: Optional[EmailStr] = Field(default=None, max_length=50)

    # 输入字段：均为可选，且不设默认值
    user_status: Optional[UserStatus] = Field(default=None)
    user_status_label: Optional[str] = None
    # 注册需要租户ID
    tenant_id: Optional[int] = Field(None)

    # noinspection PyMethodParameters
    @model_validator(mode="before")
    def resolve_enums(cls, data: Any) -> Any:
        if isinstance(data, dict):
            EnumService.resolve_field(data, "user_status", UserStatus)
        return data


class AuthPassword(SQLModel):
    """ 修改密码模型 """
    old_password: str
    new_password: str = Field(min_length=6, max_length=50)



from ..utils.response_utils import ResponseUtil as ResponseUtil
from .format_valid_error import format_pydantic_validation_error as format_pydantic_validation_error, format_request_validation_error as format_request_validation_error
from .service_exception import AuthException as AuthException, ShudaodaoException as ShudaodaoException
from fastapi import FastAPI as FastAPI, Request as Request

def register_exception_handlers(app: FastAPI): ...



#!/usr/bin/env python3
# -*- coding:utf-8 -*-
# @License  ：(C)Copyright 2025, 数道智融科技
# @Author   ：李锋
# @Software ：PyCharm
# @Date     ：2025/9/21 下午3:11
# @Desc     ：
# !/usr/bin/env python3
# -*- coding:utf-8 -*-
# @License  ：(C)Copyright 2025, 数道智融科技
# @Author   ：李锋
# @Software ：PyCharm
# @Date     ：2025/6/22 下午6:32
# @Desc     ：

from typing import List

from pydantic import BaseModel, Field


class RouterConfigSetting(BaseModel):
    name: str = Field(..., description="包名")
    enabled: bool = Field(True, description="是否启用")
    prefix: str = Field("", description="url前缀")
    tags: List[str] = Field(None, description="文档分类标签")



from ..config.app_config import AppConfig as AppConfig
from ..schemas.response import DataResponse as DataResponse, ErrorResponse as ErrorResponse
from fastapi.responses import Response as Response
from typing import Any

class ResponseUtil:
    @classmethod
    def success(cls, *, message: str = '操作成功', data: Any | None = None, name: str | None = None) -> Response: ...
    @classmethod
    def failure(cls, *, message: str = '操作失败', code: int = 500, data: Any | None = None, name: str | None = None) -> Response: ...
    @classmethod
    def error(cls, *, error: Any | None, message: str = '服务器异常', code: int = 500, name: str | None = None) -> Response: ...



class RunningConfig:
    @classmethod
    def get_sqlmodel_schema(cls, schema_name): ...
    @classmethod
    def get_controller_schema(cls, schema_name): ...
    @classmethod
    def get_engine_name(cls, engine_name, schema_name): ...



#!/usr/bin/env python3
# -*- coding:utf-8 -*-
# @License  ：(C)Copyright 2025, 数道智融科技
# @Author   ：李锋
# @Software ：PyCharm
# @Date     ：2025/9/26 下午12:21
# @Desc     ：
from pydantic import BaseModel


class EnumDisplay(BaseModel):
    value: int
    label: str
    description: str



from ..logger.logging_ import logging as logging
from typing import Any, Callable

class ClassScanner:
    @classmethod
    def find_classes(cls, package_name: str, base_class: type = ..., predicate: Callable[[type], bool] | None = None) -> dict[str, type]: ...
    @classmethod
    def find_classes_instances(cls, package_name: str, base_class: type = ..., predicate: Callable[[Any], bool] | None = None) -> dict[str, Any]: ...



from dataclasses import dataclass
from typing import Pattern

@dataclass
class AuthDataRule:
    method: str
    pattern: Pattern
    data_role: str
    data_act: str
    data_obj: str
    @staticmethod
    def convert_path_to_regex(path: str) -> Pattern: ...



from ..engine.database_engine import DatabaseEngine as DatabaseEngine
from _typeshed import Incomplete
from collections.abc import Generator

class DBEngineService:
    @classmethod
    def get_async_engine(cls, database_config_name): ...
    @classmethod
    def get_engine(cls, database_config_name): ...
    @classmethod
    async def get_async_session(cls, database_config_name: str): ...
    @classmethod
    def get_auth_async_engine(cls): ...
    @classmethod
    def get_auth_engine(cls): ...
    @classmethod
    async def get_auth_async_session(cls) -> Generator[Incomplete]: ...



from ..engine.database_engine import DatabaseEngine as DatabaseEngine
from ..logger.logging_ import logging as logging

class DatabaseChecker:
    @staticmethod
    async def metadata_to_database(source_metadata, engine_name, auto_create: bool = True): ...



#!/usr/bin/env python3
# -*- coding:utf-8 -*-
# @License  ：(C)Copyright 2025, 数道智融科技
# @Author   ：李锋
# @Software ：PyCharm
# @Date     ：2025/8/21 下午9:48
# @Desc     ：
import os
from pathlib import Path

from Cython.Build import cythonize
from setuptools import Extension, find_namespace_packages, find_packages
from setuptools import setup


def _get_cython_extensions() -> list[Extension]:
    """自动发现所有 .c 文件并为其创建 Cython 扩展对象"""
    ext_modules = []

    packages = find_packages(where=str(Path("src").resolve()))
    relative_path = Path("src")

    for package in packages:
        package_path = relative_path / package.replace('.', '/')
        for c_file in package_path.rglob("*.c"):
            # 构建模块路径
            rel_path = c_file.relative_to(relative_path)
            module_name = str(rel_path.with_suffix(''))
            if "/" in module_name:
                module_name = module_name.replace('/', '.')
            if "\\" in module_name:
                module_name = module_name.replace('\\', '.')

            compile_args = [] if os.name == 'nt' else ["-Wno-unreachable-code-fallthrough",
                                                       "-Wno-unused-function",
                                                       "-Wno-unreachable-code", ]

            ext_modules.append(
                Extension(
                    name=module_name,
                    sources=[str(c_file)],
                    extra_compile_args=compile_args,
                )
            )
    return ext_modules


setup(
    packages=find_namespace_packages(where="src"),
    package_dir={"": "src"},
    include_package_data=False,
    ext_modules=cythonize(
        _get_cython_extensions(),
        compiler_directives={
            'language_level': 3,
            'annotation_typing': True,
        },
        # quiet=True,
        annotate=True,
        nthreads=4,  # 使用多线程编译
    ),
    # script_args=['build_ext'],
    zip_safe=False,
)



#!/usr/bin/env python3
# -*- coding:utf-8 -*-
# @License  ：(C)Copyright 2025, 数道智融科技
# @Author   ：李锋
# @Software ：PyCharm
# @Date     ：2025/8/28 下午2:02
# @Desc     ：

from typing import Optional

from pydantic import BaseModel


class Paging(BaseModel):
    total: Optional[int] = None
    page: int
    size: int
    pages: Optional[int] = None
    rows: Optional[list] = None

    def set_total(self, total):
        self.total = total
        self.pages = (total + self.size - 1) // self.size





from sqlmodel import SQLModel
from typing import TypeVar

T = TypeVar('T')
SQLModelDB = TypeVar('SQLModelDB', bound=SQLModel)
SQLModelCreate = TypeVar('SQLModelCreate', bound=SQLModel)
SQLModelUpdate = TypeVar('SQLModelUpdate', bound=SQLModel)
SQLModelResponse = TypeVar('SQLModelResponse', bound=SQLModel)



from .loader import ConfigLoader as ConfigLoader
from .schemas.app_config import AppConfigSetting as AppConfigSetting
from _typeshed import Incomplete

class AppConfigLoader:
    @classmethod
    def load_config(cls) -> AppConfigSetting: ...

AppConfig: Incomplete



from functools import cache
from pathlib import Path

class CoreUtil:
    @staticmethod
    def dict_to_bytes(source: dict) -> bytes: ...
    @staticmethod
    def dict_to_str(source: dict) -> str: ...
    @classmethod
    def bytes_to_dict(cls, source: bytes): ...
    @staticmethod
    def str_to_dict(source: str) -> dict: ...
    @classmethod
    @cache
    def get_root_path(cls) -> Path: ...
    @classmethod
    def get_path(cls, path: str | Path) -> Path: ...
    @classmethod
    def get_config_path(cls) -> Path: ...
    @classmethod
    def get_web_path(cls) -> Path: ...
    @classmethod
    def get_admin_path(cls) -> Path: ...
    @staticmethod
    def remove_path(file_or_path: str | Path | None) -> None: ...



from ..engine.database_engine import DatabaseEngine as DatabaseEngine
from ..logger.logging_ import logging as logging
from ..utils.core_utils import CoreUtil as CoreUtil
from .config import GeneratorConfig as GeneratorConfig
from .meta_column import MetaColumn as MetaColumn
from .meta_foreign import MetaForeignColumn as MetaForeignColumn
from .meta_table import MetaTable as MetaTable
from .meta_view import MetaView as MetaView
from _typeshed import Incomplete
from pathlib import Path

class TemplateBuilder:
    default_factory: bool
    support_schema: Incomplete
    output: Path
    def __init__(self, *, config: GeneratorConfig) -> None: ...
    @staticmethod
    def format_column_child(column: MetaForeignColumn) -> str: ...
    @staticmethod
    def format_column_parent(column: MetaForeignColumn) -> str: ...
    @classmethod
    def format_column_base(cls, column: MetaColumn) -> str: ...
    @classmethod
    def format_column_table(cls, column: MetaColumn) -> str: ...
    @classmethod
    def format_column_response(cls, column: MetaColumn) -> str: ...
    @classmethod
    def format_column(cls, column: MetaColumn) -> str: ...
    def render_template(self, *, meta_model: MetaTable, template_name: str, child_path: str): ...
    def save_init_file(self, meta_model: MetaTable): ...
    def get_table_meta(self, table_name, schema_name) -> MetaTable: ...
    def get_view_meta(self, view_name, schema_name) -> MetaView: ...
    def get_table_names(self, *, schema_name): ...
    def get_view_names(self, *, schema_name): ...
    def get_schema_names(self): ...



import abc
from ..auth.auth_router import AuthRouter as AuthRouter
from ..config.app_config import AppConfig as AppConfig
from ..config.schemas.routers import RouterConfigSetting as RouterConfigSetting
from ..license.verify import verify_license as verify_license
from ..logger.logging_ import logging as logging
from ..portal_auth import auth_registry as auth_registry
from ..portal_auth.entity_table.auth_user import AuthRegister as AuthRegister, AuthUser as AuthUser
from ..services.auth_service import AuthService as AuthService
from ..services.casbin_service import PermissionService as PermissionService
from ..services.data_service import DataService as DataService
from ..services.db_engine_service import DBEngineService as DBEngineService
from ..tools.class_scaner import ClassScanner as ClassScanner
from ..tools.database_checker import DatabaseChecker as DatabaseChecker
from ..tools.tenant_checker import TenantManager as TenantManager
from ..utils.core_utils import CoreUtil as CoreUtil
from _typeshed import Incomplete
from abc import ABC, abstractmethod
from fastapi import FastAPI

class BaseApplication(ABC, metaclass=abc.ABCMeta):
    app: Incomplete
    def __init__(self) -> None: ...
    @abstractmethod
    def application_init(self, app: FastAPI) -> None: ...
    @abstractmethod
    async def application_load(self): ...
    @abstractmethod
    async def application_unload(self): ...
